@@ -475,3 +475,54 @@ class FRONEC(MultiLabelClassifier):
         def _Q_2(self, neighbours, R):
             vals = np.maximum(R[..., None] + self.R_d[neighbours, :] - 1, 0)
             return soft_max(vals, self.owa_weights, k=None, axis=1)
+
+
+class NN(MultiClassClassifier):
+
+    def __init__(
+            self,
+            k: int or Callable[[int], float] or None = at_most(5),
+            dissimilarity: str or float or Callable[[np.array], float] or Callable[[np.array, np.array], float] = 'boscovich',
+            distance_weighted: bool = False,
+            nn_search: NeighbourSearchMethod = KDTree(),
+            preprocessors=()
+    ):
+        super().__init__(preprocessors=preprocessors)
+        self.distance_weighted = distance_weighted
+        self.k = k
+        self.dissimilarity = resolve_dissimilarity(dissimilarity)
+        self.nn_search = nn_search
+
+    def _construct(self, X, y) -> Model:
+        model: NN.Model = super()._construct(X, y)
+        model.distance_weighted = self.distance_weighted
+        model.k = resolve_k(self.k, len(X))
+        model.nn_model = self.nn_search(X, dissimilarity=self.dissimilarity)
+        model.y = y
+        return model
+
+    class Model(MultiClassClassifier.Model):
+
+        distance_weighted: bool
+        k: int
+        nn_model: NeighbourSearchMethod.Model
+        y: np.array
+
+        def _query(self, X):
+            neighbours, distances = self.nn_model(X, k=self.k)
+            q_classes = self.y[neighbours]
+
+            vals = np.zeros((neighbours.shape[0], len(self.classes)))
+
+            if self.distance_weighted:
+                zero_distances = np.any(distances <= 0, axis=-1)
+                inv_distances = np.where(zero_distances[:, None], np.where(distances <= 0, 1, 0), 1 / distances)
+
+                for i, c in enumerate(self.classes):
+                    vals[:, i] = np.sum((q_classes == c) * inv_distances, axis=-1)
+                vals = vals / np.sum(vals, axis=-1)[:, None]
+            else:
+                for i, c in enumerate(self.classes):
+                    vals[:, i] = np.count_nonzero(q_classes == c, axis=-1)
+                vals = vals / self.k
+            return vals
